@@ -1,6 +1,6 @@
-import sys
 import shutil
 import sh
+from io import IOBase
 import tempfile
 from testfixtures import TempDirectory
 import unittest
@@ -12,12 +12,6 @@ from tssc.step_implementers.tag_source import Git
 from tests.helpers.base_tssc_test_case import BaseTSSCTestCase
 from tests.helpers.test_utils import *
 
-def Any(cls):
-    class Any(cls):
-        def __eq__(self, other):
-            return True
-    return Any()
-
 class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
 
     @patch('sh.git', create=True)
@@ -267,8 +261,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.git', create=True)
@@ -385,8 +379,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('shutil.copyfile', create=True)
@@ -627,14 +621,14 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             argocd_mock.app.get.assert_called_once_with(
                organization_name + '-' + application_name + '-' + service_name + '-testbranch-' + environment_name,
-               _out=sys.stdout,
-               _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
             argocd_mock.app.create.assert_called_once_with(
                 organization_name + '-' + application_name + '-' + service_name + '-testbranch-' + environment_name,
@@ -645,8 +639,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--dest-namespace=' + organization_name + '-' + application_name + '-' + service_name + '-testbranch-' + environment_name,
                 '--sync-policy=none',
                 '--values=values-{env}.yaml'.format(env=environment_name),
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -774,8 +768,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -898,8 +892,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -1476,8 +1470,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -1486,8 +1480,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--timeout',
                 argocd_sync_timeout_seconds,
                 organization_name + '-' + application_name + '-' + service_name + '-testbranch-' + environment_name,
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.git', create=True)
@@ -1608,8 +1602,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -1733,8 +1727,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -1859,8 +1853,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
@@ -2108,8 +2102,8 @@ class TestStepImplementerDeployArgoCD(BaseTSSCTestCase):
                 '--username=' + argocd_username,
                 '--password=' + argocd_password,
                 '--insecure',
-                _out=sys.stdout,
-                _err=sys.stderr
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
             git_mock.clone.assert_called_once()
