@@ -1,17 +1,15 @@
 import os
-import sys
 import sh
+from io import IOBase
 from pathlib import Path
-
-import unittest
 from unittest.mock import patch
+
 from testfixtures import TempDirectory
 
 from tssc import TSSCFactory
-from tssc.step_implementers.package import Maven
 
 from tests.helpers.base_tssc_test_case import BaseTSSCTestCase
-from tests.helpers.test_utils import run_step_test_with_result_validation
+from tests.helpers.test_utils import run_step_test_with_result_validation, Any
 
 def create_mvn_side_effect(pom_file, artifact_parent_dir, artifact_names):
     """simulates what mvn does by touching files.
@@ -130,15 +128,20 @@ class TestStepImplementerPackageMaven(BaseTSSCTestCase):
                 }
             }
 
-            mvn_mock.side_effect = create_mvn_side_effect(pom_file_path, 'target', [artifact_file_name])
+            mvn_mock.side_effect = create_mvn_side_effect(pom_file_path,
+                                                          'target',
+                                                          [artifact_file_name])
             run_step_test_with_result_validation(temp_dir, 'package', config, expected_step_results)
+            settings_file_path = temp_dir.path + "/tssc-working/package/settings.xml"
             mvn_mock.assert_called_once_with(
                 'clean',
                 'install',
                 '-f',
                 pom_file_path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                '-s',
+                settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.mvn', create=True)
@@ -202,8 +205,7 @@ class TestStepImplementerPackageMaven(BaseTSSCTestCase):
             with self.assertRaisesRegex(
                     ValueError,
                     'pom resulted in 0 with expected artifact extensions (.*), this is unsupported'):
-
-                    run_step_test_with_result_validation(temp_dir, 'package', config, expected_step_results)
+                run_step_test_with_result_validation(temp_dir, 'package', config, expected_step_results)
 
     @patch('sh.mvn', create=True)
     def test_mvn_multiple_jars(self, mvn_mock):
@@ -361,13 +363,16 @@ class TestStepImplementerPackageMaven(BaseTSSCTestCase):
 
             mvn_mock.side_effect = create_mvn_side_effect(pom_file_path, 'target', [artifact_file_name])
             run_step_test_with_result_validation(temp_dir, 'package', config, expected_step_results)
+            settings_file_path = temp_dir.path + "/tssc-working/package/settings.xml"
             mvn_mock.assert_called_once_with(
                 'clean',
                 'install',
                 '-f',
                 pom_file_path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                '-s',
+                settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.mvn', create=True)
@@ -420,13 +425,16 @@ class TestStepImplementerPackageMaven(BaseTSSCTestCase):
             }
             mvn_mock.side_effect = create_mvn_side_effect(pom_file_path, 'target', [artifact_file_name])
             run_step_test_with_result_validation(temp_dir, 'package', config, expected_step_results)
+            settings_file_path = temp_dir.path + "/tssc-working/package/settings.xml"
             mvn_mock.assert_called_once_with(
                 'clean',
                 'install',
                 '-f',
                 pom_file_path,
-                _out=sys.stdout,
-                _err=sys.stderr
+                '-s',
+                settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.mvn', create=True, side_effect = sh.ErrorReturnCode('mvn clean install', b'mock out', b'Failed to execute goal org.apache.maven.plugins:maven-compiler-plugin:3.1:compile (default-compile) on project my-app: Compilation failure: Compilation failure'))
