@@ -3,7 +3,7 @@
 Tests the Maven Cucumber UAT step.
 """
 from os import path, rmdir, makedirs
-from sys import stdout, stderr
+from io import IOBase
 from unittest.mock import patch
 from pathlib import Path
 from sh import ErrorReturnCode
@@ -12,7 +12,7 @@ from testfixtures import TempDirectory
 
 from tssc import TSSCFactory
 from tests.helpers.base_tssc_test_case import BaseTSSCTestCase
-from tests.helpers.test_utils import run_step_test_with_result_validation
+from tests.helpers.test_utils import run_step_test_with_result_validation, Any
 
 SELENIUM_HUB_URL = 'http://selenium:4444'
 TARGET_BASE_URL = 'http://app:8080'
@@ -332,6 +332,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                 }
             }
 
+            settings_file_path = f'{temp_dir.path}/tssc-working/uat/settings.xml'
             run_step_test_with_result_validation(temp_dir, 'uat', config, expected_step_results)
             mvn_mock.assert_called_once_with(
                 'clean',
@@ -342,8 +343,9 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                     'json:target/cucumber/cucumber.json',
                 'test',
                 '-f', pom_file_path,
-                _out=stdout,
-                _err=stderr
+                '-s', settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.mvn', create=True)
@@ -413,6 +415,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                 }
             }
 
+            settings_file_path = f'{temp_dir.path}/tssc-working/uat/settings.xml'
             run_step_test_with_result_validation(temp_dir, 'uat', config, expected_step_results)
             mvn_mock.assert_called_once_with(
                 'clean',
@@ -423,8 +426,9 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                     'json:target/cucumber/cucumber.json',
                 'test',
                 '-f', pom_file_path,
-                _out=stdout,
-                _err=stderr
+                '-s', settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     def test_uat_test_missing_surefire_plugin_in_pom(self):
@@ -444,7 +448,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                     }
                 }
             }
-            factory = TSSCFactory(config)
+            factory = TSSCFactory(config, temp_dir)
             with self.assertRaisesRegex(
                     ValueError,
                     'Uat dependency "maven-surefire-plugin" missing from POM.'):
@@ -603,6 +607,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                 }
             }
 
+            settings_file_path = f'{temp_dir.path}/tssc-working/uat/settings.xml'
             run_step_test_with_result_validation(temp_dir, 'uat', config, expected_step_results)
             mvn_mock.assert_called_once_with(
                 'clean',
@@ -613,8 +618,9 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                     'json:target/cucumber/cucumber.json',
                 'test',
                 '-f', pom_file_path,
-                _out=stdout,
-                _err=stderr
+                '-s', settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.mvn', create=True)
@@ -735,6 +741,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                 }
             }
 
+            settings_file_path = f'{temp_dir.path}/tssc-working/uat/settings.xml'
             run_step_test_with_result_validation(temp_dir, 'uat', config, expected_step_results)
             mvn_mock.assert_called_once_with(
                 'clean',
@@ -745,8 +752,9 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                     'json:target/custom-cucumber/cucumber.json',
                 'test',
                 '-f', pom_file_path,
-                _out=stdout,
-                _err=stderr
+                '-s', settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
 
     @patch('sh.mvn', create=True)
@@ -828,6 +836,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                 }
             }
 
+            settings_file_path = f'{temp_dir.path}/tssc-working/uat/settings.xml'
             run_step_test_with_result_validation(temp_dir, 'uat', config, expected_step_results)
             mvn_mock.assert_called_once_with(
                 'clean',
@@ -838,6 +847,7 @@ class TestStepImplementerUatTest(BaseTSSCTestCase):
                     'json:target/cucumber/cucumber.json',
                 'test',
                 '-f', pom_file_path,
-                _out=stdout,
-                _err=stderr
+                '-s', settings_file_path,
+                _out=Any(IOBase),
+                _err=Any(IOBase)
             )
