@@ -152,6 +152,40 @@ From least precedence to highest precedence.
         # part of the application it is a part of.
         service-name: ''
 
+        # Optional.
+        # Maven server settings for settings.xml file
+        maven-servers:
+        -  id: ''
+           username: ''
+           password: ''
+
+        # Optional.
+        # Maven repository settings for settings.xml file
+        maven-repositories:
+        - id: ''
+          url: ''
+          snapshots: ''
+          releases: ''
+
+        # Optional.
+        # Maven mirror settings for settings.xml file
+        maven-mirrors:
+        - id: ''
+          url: ''
+          mirror-of: ''
+
+        # Dictionary of container registries to authenticate with.
+        # Suggest putting in global configuration so it can be used for creating and pushing
+        # images. But can also or instead be put in the individual steps if say different
+        # registires are used for building images then pushing them.
+        #container-registries:
+        #  registry.redhat.io:
+        #    username: account_number|acount_name
+        #    password: encrypt_me
+        #  registry.internal.example.xyz:
+        #    username: team_name+project_name
+        #    password: encrypt_me
+
       # Optional
       # Dictionary of dictionaries where the first level keys are environment names and their
       # dictionary values are configuration defaults to use when invoking a step in the context
@@ -308,13 +342,12 @@ From least precedence to highest precedence.
         config: {
           # Required.
           # URL to the artifact repository to push the artifact to.
-          url: ''
+          maven-push-artifact-repo-url: ''
 
-          # Optional.
-          #user: None
+          # Required.
+          # Id to the artifact repository to push the artifact to.
+          maven-push-artifact-repo-id: ''
 
-          # Optional.
-          #password: None
         }
 
       create-container-image:
@@ -442,6 +475,19 @@ From least precedence to highest precedence.
         # part of the application it is a part of.
         service-name: ''
 
+        # Optional.
+        # Dictionary of container registries to authenticate with.
+        # Suggest putting in global configuration so it can be used for creating and pushing
+        # images. But can also or instead be put in the individual steps if say different
+        # registires are used for building images then pushing them.
+        #container-registries:
+        #  registry.redhat.io:
+        #    username: account_number|acount_name
+        #    password: encrypt_me
+        #  registry.internal.example.xyz:
+        #    username: team_name+project_name
+        #    password: encrypt_me
+
       # Optional
       # Dictionary of dictionaries where the first level keys are environment names and their
       # dictionary values are configuration defaults to use when invoking a step in the context
@@ -581,17 +627,7 @@ From least precedence to highest precedence.
       push-artifacts:
       # WARNING: not yet implemented
       - implementer: NPM
-        config: {
-          # Required.
-          # URL to the artifact repository to push the artifact to.
-          url: ''
-
-          # Optional.
-          #user: None
-
-          # Optional.
-          #password: None
-        }
+        config: {}
 
       create-container-image:
       - implementer: Buildah
@@ -701,12 +737,9 @@ Example Running the 'generate-metadata' step
 """
 
 import __main__
-from .config import *
-from .decryption_utils import DecryptionUtils
-from .factory import *
-from .exceptions import *
-from .step_implementer import DefaultSteps, StepImplementer
-from .utils import *
+from .step_implementer import StepImplementer, DefaultSteps
+from .factory import TSSCFactory
+from .exceptions import TSSCException
 
 __all__ = [
     'config',
